/*
 * Copyright [2022] [https://www.xiaonuo.vip]
 *
 * Snowy采用APACHE LICENSE 2.0开源协议，您在使用过程中，需要注意以下几点：
 *
 * 1.请不要删除和修改根目录下的LICENSE文件。
 * 2.请不要删除和修改Snowy源码头部的版权声明。
 * 3.本项目代码可免费商业使用，商业使用请保留源码和相关描述文件的项目出处，作者声明等。
 * 4.分发源码时候，请注明软件出处 https://www.xiaonuo.vip
 * 5.不可二次分发开源参与同类竞品，如有想法可联系团队xiaonuobase@qq.com商议合作。
 * 6.若您的项目无法满足以上几点，需要更多功能代码，获取Snowy商业授权许可，请在官网购买授权，地址为 https://www.xiaonuo.vip
 */
package com.chinaitop.depot.sqr.controller;


import com.chinaitop.depot.sqr.model.BizSqrEnterpriseApply;
import com.chinaitop.depot.sqr.model.vo.BizSqrEnterpriseApplyVO;
import com.chinaitop.depot.sqr.service.BizSqrEnterpriseApplyService;
import com.fasterxml.jackson.core.JsonParseException;
import com.fasterxml.jackson.databind.JsonMappingException;
import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.web.bind.annotation.*;


import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import java.io.IOException;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * 粮食储备-承储资格企业-承储资格申请控制器
 *
 * @author ZeroLiYi
 * @date  2024/04/28 10:01
 */
@RestController
@RequestMapping(value="/sqr")
@Api(description = "承储资格申请控制器")
public class BizSqrEnterpriseApplyController {

    @Resource
    private BizSqrEnterpriseApplyService bizGrQeApplyService;

    /**
     * 获取粮食储备-承储资格企业-承储资格申请分页
     *
     * @author ZeroLiYi
     * @date  2024/04/28 10:01
     */
    @ApiOperation("承储资格申请分页")
    @GetMapping("/page")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "页码", paramType = "query"),
            @ApiImplicitParam(name = "pageSize", value = "每页条数", paramType = "query"),
            @ApiImplicitParam(name = "dwmc", value = "单位名称", paramType = "query"),
            @ApiImplicitParam(name = "applyType", value = "申请类型", paramType = "query")

    })
    public PageInfo<BizSqrEnterpriseApply> page(Integer pageNum, Integer pageSize,String dwmc,Integer applyType,String unitInfoId) {

        if (pageNum!=null && pageSize!=null) {
            PageHelper.startPage(pageNum, pageSize);
        }
        List<BizSqrEnterpriseApply> list = bizGrQeApplyService.findByPage(dwmc,applyType,unitInfoId);
        PageInfo<BizSqrEnterpriseApply> pageInfo = new PageInfo<BizSqrEnterpriseApply>(list);
        return pageInfo;
    }


    
    @ApiOperation("承储资格申请详情")
    @GetMapping("/findById")
    @ApiImplicitParams({

            @ApiImplicitParam(name = "id", value = "申请记录唯一标识符", paramType = "query")

    })
    public BizSqrEnterpriseApplyVO findById(Integer applyType,String unitInfoId,Integer id) {


        BizSqrEnterpriseApplyVO bizSqrEnterpriseApplyVO = bizGrQeApplyService.findById(applyType,unitInfoId,id);
        return bizSqrEnterpriseApplyVO;
    }

    /**
     * 添加粮食储备-承储资格企业-承储资格申请
     *
     * @author ZeroLiYi
     * @date  2024/04/28 10:01
     */
    @ApiOperation("新增承储资格申请")
    @PostMapping("/add")
    public Map<String, Object> save(@RequestBody BizSqrEnterpriseApply bizSqrEnterpriseApply) {
        Map<String, Object> modelMap = new HashMap<>();
        try {
            modelMap = bizGrQeApplyService.saveOrUpdate(bizSqrEnterpriseApply);
        } catch (Exception e) {
            e.printStackTrace();
            modelMap.put("status", "error");
            modelMap.put("msg", "保存失败！");
        } finally {
            return modelMap;
        }
    }

    /**
     * 
     * 删除承储资格申请
     *
     * @author ZeroLiYi
     * @date  2024/04/28 10:01
     */
    @RequestMapping(value="/remove", method = RequestMethod.POST)
    @ApiOperation(value="删除承储资格申请", notes = "根据申请记录唯一标识符删除")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "enterpriseApplyId", value = "申请记录唯一标识符", paramType = "form")
    })
    public Map<String, Object> remove(Integer enterpriseApplyId){
        Map<String, Object> modelMap = new HashMap<>();
        if (enterpriseApplyId != null) {
        	bizGrQeApplyService.deleteById(enterpriseApplyId);
        }
        modelMap.put("status", "success");
        return modelMap;
    }

    /**
     * 获取粮食储备-承储资格企业-承储资格申请详情
     *
     * @author ZeroLiYi
     * @date  2024/04/28 10:01
     */
//    @ApiOperationSupport(order = 5)
//    @ApiOperation("获取粮食储备-承储资格企业-承储资格申请详情")
//    @SaCheckPermission("/biz/grqeapply/detail")
//    @GetMapping("/biz/grqeapply/detail")
//    public CommonResult<BizGrQeApply> detail(@Valid BizGrQeApplyIdParam bizGrQeApplyIdParam) {
//        return CommonResult.data(bizGrQeApplyService.detail(bizGrQeApplyIdParam));
//    }
}
